pub struct Segmenter<const C: usize, S> {
inner: S,
state: State,
frame: Vec<u8>,
ready_segments: VecDeque<Segment>,
frame_size: usize,
frame_id: FrameId,
is_closed: bool,
send_terminating_segment: bool,
}Expand description
Segmenter is an adaptor to [futures::Sink] of Segment items
that turns it into [futures::io::AsyncWrite].
Bytes written to the Segmenter are buffered up and/or chopped into Segment
of at most C in payload size (the data member).
The bytes are written to the
underlying Sink once more than frame_size is written (or unless flushed),
so the Segmenter naturally acts as a buffered writer.
Any unflushed bytes written to the Segmenter will be lost when it is closed.
The data are grouped into Frames of the size given by the frame_size
parameter, segments in each such group share the same FrameId.
This acts as a natural buffering feature of a Segmenter.
Segmenter can optionally send a terminating when poll_close
is called.
Segmenter is essentially inverse of Reassembler.
Use SegmenterExt to turn a Segment sink into an AsyncWrite object using the Segmenter.
Fields
inner: Sstate: Stateframe: Vec<u8>ready_segments: VecDeque<Segment>frame_size: usizeframe_id: FrameIdis_closed: boolsend_terminating_segment: boolImplementations